===========
Camelot API
===========


.. automodule:: camelot
   :members:

.. toctree::

   admin/index.rst
   art/index.rst
   bin/index.rst
   container/index.rst
   core/index.rst
   model/index.rst
   test/index.rst
   types/index.rst
   view/index.rst
